@@ -31,14 +31,14 @@ class TestBlanketCutterParallels(unittest.TestCase):
         assert self.test_shape.solid is not None
         assert self.test_shape.volume > 1000
 
-    # def test_BlanketCutterParallels_distance_volume_impact(self):
-    #     """Creates solid using the BlanketCutterParallels parametric component
-    #     with different distances and checks that the volume changes accordingly
-    #     ."""
+    def test_BlanketCutterParallels_distance_volume_impact(self):
+        """Creates solid using the BlanketCutterParallels parametric component
+        with a larger thickness and checks that the volume changes accordingly
+        ."""
 
-    #     test_volume = self.test_shape.volume
-    #     self.test_shape.thickness=100
-    #     assert test_volume < self.test_shape.volume
+        test_volume = self.test_shape.volume
+        self.test_shape.thickness = 100
+        assert test_volume < self.test_shape.volume
 
     def test_cut_modification(self):
         """Creates a BlanketCutterParallels parametric component and with another
