@@ -1,6 +1,7 @@
 
 import os
 import unittest
+import pytest
 from pathlib import Path
 
 import paramak
@@ -223,12 +224,11 @@ class TestPlasma(unittest.TestCase):
         assert Path("plasma.stp").exists()
         os.system("rm plasma.stp")
 
-    # TODO: fix issue #435
-    # def test_plasma_relative_volume(self):
-    #     """Creates plasmas using the Plasma parametric component and checks that
-    #     the relative volumes of the solids created are correct"""
+    def test_plasma_relative_volume(self):
+        """Creates plasmas using the Plasma parametric component and checks that
+        the relative volumes of the solids created are correct"""
 
-    #     test_plasma = paramak.Plasma()
-    #     test_plasma_volume = test_plasma.volume
-    #     test_plasma.rotation_angle = 180
-    #     assert test_plasma.volume == pytest.approx(test_plasma_volume * 0.5)
+        test_plasma = paramak.Plasma()
+        test_plasma_volume = test_plasma.volume
+        test_plasma.rotation_angle = 180
+        assert test_plasma.volume == pytest.approx(test_plasma_volume * 0.5)
